/**
 * Copyright (c) 2009-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.registry.core.repository.bo;


import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.Lob;
import javax.persistence.Table;

import org.hibernate.annotations.GenericGenerator;

/**
 * The endpoint BO contains all the data in a single table for access performance.
 * 
 * @author Christophe HAMERLING - EBM WebSourcing
 * @author Charles CASADEI - EBM WebSourcing
 */
@Entity
@Table(name="Endpoint")
public class Endpoint {


    private String id;
    
    private String description;
    
    private String name;

    private String service;

    private String rootRegistry;

    private String path;

    private long creationTime;

    private String interfaceName;

    private String container;

    private String component;

    private String subdomain;

    private String type;

    public Endpoint() {
    }

    @Id
    @GeneratedValue(generator = "system-uuid")
    @GenericGenerator(name = "system-uuid", strategy = "uuid")
    public String getId() {
        return this.id;
    }

    public void setId(String id) {
        this.id = id;
    }
    
    @Lob
    @Column(name="description", length=16777214)
    public String getDescription() {
        return this.description;
    }
    
    public void setDescription(String description) {
        this.description = description;
    }
    
    @Column(name="name", nullable=false)
    @org.hibernate.annotations.Index(name="IDX_EP_NAME")
    public String getName() {
        return this.name;
    }
    
    public void setName(String name) {
        this.name = name;
    }
    
    @Column(name="service", nullable=false)
    @org.hibernate.annotations.Index(name="IDX_EP_SERVICE")
    public String getService() {
        return this.service;
    }
    
    public void setService(String service) {
        this.service = service;
    }

    @Column(name="rootRegistry", nullable=false)
    public String getRootRegistry() {
        return this.rootRegistry;
    }

    public void setRootRegistry(String rootRegistry) {
        this.rootRegistry = rootRegistry;
    }
    
    @Column(name="creationTime")
    public long getCreationTime() {
        return this.creationTime;
    }
    
    public void setCreationTime(long creationTime) {
        this.creationTime = creationTime;
    }
    
    @Column(name="eppath", unique = true, nullable=false)
    public String getPath() {
        return this.path;
    }

    public void setPath(String path) {
        this.path = path;
    }

    @Column(name="interfaceName", nullable=false)
    @org.hibernate.annotations.Index(name="IDX_EP_INTERFACE")
    public String getInterfaceName() {
        return this.interfaceName;
    }

    public void setInterfaceName(String interfaceName) {
        this.interfaceName = interfaceName;
    }

    @Column(name="container", nullable=false)
    public String getContainer() {
        return this.container;
    }

    public void setContainer(String container) {
        this.container = container;
    }

    @Column(name="component", nullable=false)
    public String getComponent() {
        return this.component;
    }

    public void setComponent(String component) {
        this.component = component;
    }

    @Column(name="subdomain", nullable=false)
    public String getSubdomain() {
        return this.subdomain;
    }

    public void setSubdomain(String subdomain) {
        this.subdomain = subdomain;
    }

    @Column(name="type")
    public String getType() {
        return this.type;
    }

    public void setType(String type) {
        this.type = type;
    }

}
