/**
 * Copyright (c) 2009-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.registry.core.transport;

import java.net.URI;
import java.util.HashMap;
import java.util.Map;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.ow2.petals.registry.api.transport.MessageSender;
import org.ow2.petals.registry.api.transport.MessageSenderManager;
import org.ow2.petals.registry.core.transport.cxf.CXFMessageSender;

/**
 * @author Christophe HAMERLING - EBM WebSourcing
 */
public class MessageSenderManagerImpl implements MessageSenderManager {

    private static Log logger = LogFactory.getLog(MessageSenderManagerImpl.class);

    /**
     * One URI is linked to one message sender
     */
    private Map<URI, MessageSender> senders;

    public MessageSenderManagerImpl() {
        this.senders = new HashMap<URI, MessageSender>();
    }

    /*
     * (non-Javadoc)
     * 
     * @see
     * org.ow2.petals.registry.api.transport.MessageSenderManager#getMessageSender
     * (java.net.URI)
     */
    public MessageSender getMessageSender(URI uri) {
        logger.debug("Get a message sender for " + uri.toString());

        if (this.senders.get(uri) == null) {
            MessageSender sender = new CXFMessageSender();
            sender.setURI(uri);
            senders.put(uri, sender);
        }
        return this.senders.get(uri);
    }

}
