/**
 * Copyright (c) 2009-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.registry.core.ws.service;

import java.util.ArrayList;
import java.util.List;

import javax.jws.WebService;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.ow2.petals.registry.api.LocalRegistry;
import org.ow2.petals.registry.api.Resource;
import org.ow2.petals.registry.api.exception.RegistryException;
import org.ow2.petals.registry.api.ws.RemoteRegistryException;
import org.ow2.petals.registry.api.ws.service.RegistryClientService;
import org.ow2.petals.registry.api.ws.to.Endpoint;
import org.ow2.petals.registry.core.ws.adapters.AdaptersManager;

/**
 * The registry client WS implementation used by clients to access to the
 * registry and to work with endpoints (not intended to be used by registries to
 * exchange resources).
 * 
 * @author Christophe HAMERLING - EBM WebSourcing
 */
@WebService
public class RegistryClientServiceImpl implements RegistryClientService {

    private static Log logger = LogFactory.getLog(RegistryClientServiceImpl.class);

    /**
     * The reference to the local registry since this service is just an access
     * point to the local registry to clients.
     */
    private final LocalRegistry localRegistry;

    public RegistryClientServiceImpl(LocalRegistry localRegistry) {
        this.localRegistry = localRegistry;
    }

    public boolean delete(String path, boolean b) throws RemoteRegistryException {
        logger.debug("Got a client delete of " + path);
        try {
            return this.localRegistry.delete(path, b);
        } catch (RegistryException e) {
            throw new RemoteRegistryException(e.getMessage());
        }
    }

    public Endpoint get(String path, boolean b) throws RemoteRegistryException {
        logger.debug("Got a client get of " + path);

        Endpoint result = null;
        Resource r = null;
        try {
            r = this.localRegistry.get(path, b);
        } catch (RegistryException e) {
            throw new RemoteRegistryException(e.getMessage());
        }
        if (r != null) {
            result = AdaptersManager.getEndpointAdapter().toWSEndpoint(r.getEndpoint());
        }
        return result;
    }

    public boolean put(String path, Endpoint endpoint, boolean b) throws RemoteRegistryException {
        logger.debug("Got a client put into " + path);

        if (endpoint == null) {
            throw new RemoteRegistryException("Endpoint is null");
        }
        org.ow2.petals.registry.api.Endpoint e = AdaptersManager.getEndpointAdapter()
                .toRegistryEndpoint(endpoint);
        Resource r = new Resource(e);
        try {
            return this.localRegistry.put(path, r, b);
        } catch (RegistryException e1) {
            throw new RemoteRegistryException(e1.getMessage());
        }
    }

    public List<Endpoint> getAll(String path, boolean b) throws RemoteRegistryException {
        logger.debug("Got a client getall of " + path);

        List<Endpoint> result = null;
        List<Resource> r = null;
        try {
            r = this.localRegistry.getAll(path, b);
        } catch (RegistryException e) {
            throw new RemoteRegistryException(e.getMessage());
        }
        if (r != null) {
            result = new ArrayList<Endpoint>(r.size());
            for (Resource resource : r) {
                result.add(AdaptersManager.getEndpointAdapter()
                        .toWSEndpoint(resource.getEndpoint()));
            }
        }
        return result;
    }

}
